(function() {

	var enDash,
		emDash,
		hairSpace,
		hairSpaceRegExp,
		started,
		waitStartTime;

	enDash = "\u2013";
	emDash = "\u2014";
	hairSpace = "\u200a";
	hairSpaceRegExp = new RegExp("(\\s*)(" + enDash + "|" + emDash + ")(\\s*)", "g");

	function handleTextNode(node, parentNode) {
		var content,
			node2;

		content = node.textContent || node.innerText || "";

		if (content && hairSpaceRegExp.test(content)) {
			content = content.replace(hairSpaceRegExp, function(match, p1, p2, p3) {
				if (!p1 && !p3) {
					return p2;
				}

				if (!p1) {
					return p2 + hairSpace;
				}

				if (!p3) {
					return hairSpace + p2;
				}

				return hairSpace + p2 + hairSpace;
			});

			node2 = document.createTextNode(content);

			parentNode.replaceChild(node2, node);
		}
	}

	function recursiveWalkFromNode(node) {
		var childNodes,
			childNodesLength,
			node2,
			i;

		if (node) {
			childNodes = node.childNodes;
			childNodesLength = childNodes.length;

			for (i = 0; i < childNodesLength; ++i) {
				node2 = childNodes[i];

				if (node2) {
					switch (node2.nodeType) {
					case 3:
						handleTextNode(node2, node);
						break;
					case 1:
						recursiveWalkFromNode(node2);
						break;
					}
				}
			}
		}
	}

	started = false;

	function start() {
		if (!started) {
			started = true;
		} else {
			return;
		}

		recursiveWalkFromNode(document.body);
	}

	function addEvent(target, type, listener) {
		var listenerOld,
			prefixedType;

		if (typeof target.addEventListener === "function") {
			target.addEventListener(type, listener, false);
		} else {
			prefixedType = "on" + type;

			if (typeof window.attachEvent === "function") {
				target.attachEvent(prefixedType, listener);
			} else {
				listenerOld = window[prefixedType];

				if (typeof listenerOld === "function") {
					target[prefixedType] = function(e) {
						listenerOld(e);
						listener(e);
					};
				} else {
					window[prefixedType] = listener;
				}
			}
		}
	}

	try {
		addEvent(window, "load", start);
	} catch(e) {} finally {
		waitStartTime = +(new Date());

		(function wait() {
			switch (document.readyState) {
				case "complete":
					start();
				break;
				default:
					if ((+(new Date())) - waitStartTime > 19999) {
						start();
					} else {
						setTimeout(wait, 10);
					}
			}
		})();
	}

})();